@@ -5,8 +5,8 @@ use warnings;
 
 use IO::All;
 
-my ($version) = 
-    (map { m{\$VERSION *= *'([^']+)'} ? ($1) : () } 
+my ($version) =
+    (map { m{\$VERSION *= *'([^']+)'} ? ($1) : () }
     io->file('lib/Statistics/Descriptive.pm')->getlines()
     )
     ;
@@ -16,13 +16,10 @@ if (!defined ($version))
     die "Version is undefined!";
 }
 
-my $mini_repos_base = 'https://svn.berlios.de/svnroot/repos/web-cpan/Statistics-Descriptive';
-
 my @cmd = (
-    "svn", "copy", "-m",
+    "hg", "tag", "-m",
     "Tagging the Statistics-Descriptive release as $version",
-    "$mini_repos_base/trunk",
-    "$mini_repos_base/tags/releases/$version",
+    "releases/$version",
 );
 
 print join(" ", @cmd), "\n";
